/*******************************************************************************
 * OSUG-DOI project ( http://doi.osug.fr ) - Copyright (C) CNRS.
 ******************************************************************************/
package fr.osug.doi;

import fr.osug.doi.service.DataciteClient;
import fr.osug.doi.service.DoiService;
import fr.osug.xml.XmlFactory;
import fr.osug.xml.validator.XmlValidatorFactory;
import java.io.IOException;
import java.util.Arrays;
import javax.annotation.PostConstruct;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.ApplicationContext;
import org.springframework.context.annotation.Configuration;

/**
 *
 */
@Configuration
@ConfigurationProperties(prefix = "osug.doi")
public class DOIConfig {

    private final static Logger logger = LoggerFactory.getLogger(DOIConfig.class.getName());

    @Autowired
    private ApplicationContext appCtx;

    @Autowired
    private XmlFactory xmlFactory;
    @Autowired
    private XmlValidatorFactory xmlValidatorFactory;

    @Autowired
    private DoiService doiService;

    @Autowired
    private DataciteConfig dataciteConfig;

    /** path config */
    private PathConfig pathConfig;

    /** debug flag */
    private boolean debug = false;

    /** DOI Prefix (registered in datacite) */
    private String prefix;

    /** DOI Domain (registered in datacite) */
    private String domain;

    /** enable/disable the Datacite API client (REST) */
    private boolean dataciteClientEnabled;

    @PostConstruct
    public void initialize() {
        try {
            this.pathConfig = new PathConfig(Paths.DIR_WEB);
        } catch (IOException ioe) {
            throw new IllegalStateException("Invalid paths: ", ioe);
        }

        this.debug = Arrays.asList(appCtx.getEnvironment().getActiveProfiles()).contains("debug");

        logger.info("debug mode: {}", debug);
        logger.info("doi prefix: {}", prefix);
        logger.info("doi domain: {}", domain);
        logger.info("Enable Datacite Client: {}", isDataciteClientEnabled());
    }

    public PathConfig getPathConfig() {
        return pathConfig;
    }

    public boolean isDebug() {
        return debug;
    }

    public ApplicationContext getAppCtx() {
        return appCtx;
    }

    public XmlFactory getXmlFactory() {
        return xmlFactory;
    }

    public XmlValidatorFactory getXmlValidatorFactory() {
        return xmlValidatorFactory;
    }

    public DoiService getDoiService() {
        return doiService;
    }

    public DataciteClient getDataciteClient() {
        return dataciteConfig.getClient();
    }

    public String getPrefix() {
        return prefix;
    }

    public void setPrefix(String prefix) {
        this.prefix = prefix;
    }

    public String getDomain() {
        return domain;
    }

    public void setDomain(String domain) {
        this.domain = domain;
    }

    public boolean isDataciteClientEnabled() {
        return dataciteClientEnabled;
    }

    public void setDataciteClientEnabled(final boolean dataciteClientEnabled) {
        this.dataciteClientEnabled = dataciteClientEnabled;
    }

}
