/*******************************************************************************
 * OSUG-DOI project ( http://doi.osug.fr ) - Copyright (C) CNRS.
 ******************************************************************************/
package fr.osug.doi;

import fr.osug.doi.validation.WarningMessage;
import java.util.ArrayList;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 *
 */
public final class ProcessPipelineDoiData {

    private final static Logger logger = LoggerFactory.getLogger(ProcessPipeline.class.getName());

    /* members */
    private final String doiId;
    private final String doiSuffix;
    /** doi title */
    private final String title;
    /** validation messages */
    private final List<WarningMessage> messages = new ArrayList<WarningMessage>();
    /** valid flag */
    private boolean valid;
    /** md5 metadata */
    private String metadataMd5;
    /* data access URL */
    private String dataAccessUrl;
    /* external Landing page URL */
    private String landingPageExtUrl;
    /* Local Landing page URL (staging) */
    private String landingLocUrl;

    ProcessPipelineDoiData(final String doiId, final String doiSuffix, final String title) {
        this.doiId = doiId;
        this.doiSuffix = doiSuffix;
        this.title = title;
        this.valid = true;
    }

    /**
     * Add the given message to the error messages
     * @param msg message to add
     */
    public void addError(final String msg) {
        setValid(false);
        logger.error(msg);
        messages.add(new WarningMessage(msg, WarningMessage.Level.Error));
    }

    /**
     * Add the given message to the warning messages
     * @param msg message to add
     */
    public void addWarning(final String msg) {
        setValid(false);
        logger.warn(msg);
        messages.add(new WarningMessage(msg, WarningMessage.Level.Warning));
    }

    /**
     * Add the given message to the information messages
     * @param msg message to add
     */
    public void addInfo(final String msg) {
        logger.info(msg);
        messages.add(new WarningMessage(msg, WarningMessage.Level.Information));
    }

    public String messagesToString() {
        final StringBuilder sb = new StringBuilder(1024);
        for (WarningMessage msg : messages) {
            sb.append(msg.getLevel()).append(" : ");
            sb.append(msg.getMessage()).append("\n");
        }
        return sb.toString();
    }

    public String getDoiId() {
        return doiId;
    }

    public String getDoiSuffix() {
        return doiSuffix;
    }

    public boolean isValid() {
        return valid;
    }

    void setValid(boolean valid) {
        this.valid = valid;
    }

    public String getTitle() {
        return title;
    }

    public String getMetadataMd5() {
        return metadataMd5;
    }

    public void setMetadataMd5(final String metadataMd5) {
        this.metadataMd5 = metadataMd5;
    }

    public String getDataAccessUrl() {
        return dataAccessUrl;
    }

    public void setDataAccessUrl(final String dataAccessUrl) {
        this.dataAccessUrl = dataAccessUrl;
    }

    public String getLandingPageExtUrl() {
        return landingPageExtUrl;
    }

    public void setLandingPageExtUrl(final String landingPageUrl) {
        this.landingPageExtUrl = landingPageUrl;
    }

    public String getLandingLocUrl() {
        return landingLocUrl;
    }

    public void setLandingLocUrl(final String landingLocUrl) {
        this.landingLocUrl = landingLocUrl;
    }

}
