/*******************************************************************************
 * OSUG-DOI project ( http://doi.osug.fr ) - Copyright (C) CNRS.
 ******************************************************************************/
package fr.osug.doi.domain;

import java.util.Objects;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.ManyToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import org.springframework.data.domain.Persistable;

/**
 * A Doi.
 */
@Entity
@Table(name = "doi")
public class Doi implements Persistable<Long> {

    private static final long serialVersionUID = 1L;

    @Id
    @SequenceGenerator(name = "doi_id_seq", sequenceName = "doi_id_seq", initialValue = 1, allocationSize = 10)
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "doi_id_seq")
    private Long id;

    @ManyToOne(optional = false)
    private Project project;

    @Column(name = "identifier", unique = true, nullable = false)
    private String identifier;

    @Column(name = "description")
    private String description;

    @Enumerated(EnumType.STRING)
    @Column(name = "status")
    private Status status = Status.STAGING;

    @Column(name = "data_access_url")
    private String dataAccessUrl;

    @Column(name = "landing_ext_url")
    private String landingExtUrl;

    @Override
    public Long getId() {
        return id;
    }

    @Override
    public boolean isNew() {
        return id == null;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Project getProject() {
        return project;
    }

    public void setProject(Project project) {
        this.project = project;
    }

    public String getIdentifier() {
        return identifier;
    }

    public void setIdentifier(String identifier) {
        this.identifier = identifier;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Status getStatus() {
        return status;
    }

    public void setStatus(Status status) {
        this.status = status;
    }

    public String getDataAccessUrl() {
        return dataAccessUrl;
    }

    public void setDataAccessUrl(String dataAccessUrl) {
        this.dataAccessUrl = dataAccessUrl;
    }

    public String getLandingExtUrl() {
        return landingExtUrl;
    }

    public void setLandingExtUrl(String landingExtUrl) {
        this.landingExtUrl = landingExtUrl;
    }

    @Override
    public int hashCode() {
        int hash = 3;
        hash = 17 * hash + Objects.hashCode(this.identifier);
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Doi other = (Doi) obj;
        if (!Objects.equals(this.identifier, other.identifier)) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "Doi{"
                + "id=" + id
                + ", project=[" + ((project != null) ? project.getName() : "NULL") + "]"
                + ", identifier='" + identifier + "'"
                + ", description='" + description + "'"
                + ", status='" + status + "'"
                + ", dataAccessUrl='" + dataAccessUrl + "'"
                + ", landingExtUrl='" + landingExtUrl + "'"
                + '}';
    }
}
